## v0.2.0 (2024-10-04)

### Feat

- add automatic issue linking and more customization option ([9faf8be](https://github.com/kmnhan/cz-changeup/commit/9faf8be3db978a27036cfa499a09e62014b50846))

[main e92202f] bump: version 0.1.2 → 0.2.0
 2 files changed, 7 insertions(+), 1 deletion(-)

